@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2014                                               *
+ *   copyright (C) 2003-2020                                               *
  *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
  ***************************************************************************/
 
@@ -27,7 +27,7 @@ class UMLAssociation;
  * @short Non-graphical information for a Package.
  * @author Jonathan Riddell
  * @see UMLCanvasObject
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
 class UMLPackage : public UMLCanvasObject
 {
@@ -40,12 +40,12 @@ public:
 
     virtual UMLObject* clone() const;
 
-    bool addObject(UMLObject *pObject);
+    bool addObject(UMLObject *pObject, bool interactOnConflict = true);
     void removeObject(UMLObject *pObject);
 
     virtual void removeAllObjects();
 
-    UMLObjectList &containedObjects();
+    UMLObjectList containedObjects(bool includeInactive = false);
 
     void addAssocToConcepts(UMLAssociation* assoc);
     void removeAssocFromConcepts(UMLAssociation *assoc);
